<!DOCTYPE TS><TS>
<context>
    <name>GuideGrid</name>
    <message>
        <source>Recording Once</source>
        <translation type="obsolete">Eenmalig Opnemen</translation>
    </message>
    <message>
        <source>Timeslot Recording</source>
        <translation type="obsolete">Opnemen per Tijdsblok</translation>
    </message>
    <message>
        <source>Channel Recording</source>
        <translation type="obsolete">Opnemen per Kanaal</translation>
    </message>
    <message>
        <source>All Recording</source>
        <translation type="obsolete">Alles Opnemen</translation>
    </message>
    <message>
        <source>Not Recording</source>
        <translation type="obsolete">Niet Opnemen</translation>
    </message>
    <message>
        <source>Weekly Recording</source>
        <translation type="obsolete">Wekelijks Opnemen</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Aflevering</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Beschrijving</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown anywhere</source>
        <translation>Dit programma altijd en op alle kanalen opnemen</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown on this channel</source>
        <translation>Dit programma altijd op dit kanaal opnemen</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every day</source>
        <translation>Dit programma dagelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every week</source>
        <translation>Dit programma wekelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Record only this showing of the program</source>
        <translation>Enkel deze vertoning van het programma opnemen</translation>
    </message>
    <message>
        <source>Don&apos;t record this program</source>
        <translation>Dit programma niet opnemen</translation>
    </message>
    <message>
        <source>To go to the advanced recordings screen, press &apos;i&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To see a list of all up-coming showings of this program, press &apos;5&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManualBox</name>
    <message>
        <source>Manual Recording</source>
        <translation>Manuele Opname</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Subtitle:</source>
        <translation>Afleveringstitel:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Speelduur:</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Begin</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Einde</translation>
    </message>
</context>
<context>
    <name>ManualSchedule</name>
    <message>
        <source>Manual Recording Scheduler</source>
        <translation>Manuele Opname Planner</translation>
    </message>
    <message>
        <source>Channel:</source>
        <translation>Kanaal:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tijd:</translation>
    </message>
    <message>
        <source>hr</source>
        <translation>uur</translation>
    </message>
    <message>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Speelduur:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Subtitle:</source>
        <translation>Afleveringstitel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <source>Save this scheduled recording and exit</source>
        <translation>Bewaar deze geplande opname en sluit af</translation>
    </message>
    <message>
        <source>Save this scheduled recording and set another</source>
        <translation>Bewaar deze geplande opname en plan een nieuwe opname</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Manual recording</source>
        <translation>Manuele opname</translation>
    </message>
</context>
<context>
    <name>MythContext</name>
    <message>
        <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection to the master backend server has gone away for some reason.. Is it running?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythWizard</name>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NuppelVideoPlayer</name>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">Overslaan</translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>% used</source>
        <translation>% gebruikt</translation>
    </message>
    <message>
        <source>, %d,%03d MB free</source>
        <translation>, %d,%03d MB vrij</translation>
    </message>
    <message>
        <source>All Programs</source>
        <translation>Alle programma&apos;s</translation>
    </message>
    <message>
        <source>You have finished watching:</source>
        <translation>U bent klaar met het bekijken van:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete:</source>
        <translation>Bent U zeker van het verwijderen van:</translation>
    </message>
    <message>
        <source>Delete this recording? It will be gone forever.</source>
        <translation type="obsolete">Verwijder deze opname? Ze verdwijnt voorgoed.</translation>
    </message>
    <message>
        <source>It will be gone forever.</source>
        <translation type="obsolete">Ze verdwijnt voorgoed.</translation>
    </message>
    <message>
        <source>Yes, get rid of it</source>
        <translation>Ja, verwijder deze opname</translation>
    </message>
    <message>
        <source>No, I might want to watch it again.</source>
        <translation>Nee, bewaar deze opname.</translation>
    </message>
    <message>
        <source>No, keep it, I changed my mind</source>
        <translation>Nee, bewaar de opname, ik heb me bedacht.</translation>
    </message>
    <message>
        <source>Delete this recording?</source>
        <translation>Deze opname verwijderen?</translation>
    </message>
    <message>
        <source>Allow this program to AutoExpire?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, AutoExpire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, stop recording it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No, do not AutoExpire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No, continue recording it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Auto Expire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleer</translation>
    </message>
    <message>
        <source>Yes; allow re-recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProgFinder</name>
    <message>
        <source>No Programs</source>
        <translation>Geen Programma&apos;s</translation>
    </message>
    <message>
        <source>There are no available programs under this search. Please select another search.</source>
        <translation>Er zijn geen programma&apos;s gevonden. Probeer een andere zoekopdracht.</translation>
    </message>
    <message>
        <source>Recording just this showing</source>
        <translation>Neem enkel deze vertoning op</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="obsolete">Neem enkel vertoningen op in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation>Neem enkel vertoningen op dit kanaal op</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation>Neem alle vertoningen op</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation>Neem deze vertoning niet op</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation>Fout!</translation>
    </message>
    <message>
        <source>       !! No Programs !!</source>
        <translation>       !! Geen programma&apos;s !!</translation>
    </message>
    <message>
        <source>Recording every day when shown in this timeslot</source>
        <translation>Dagelijkse vertoningen opnemen in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording every week when shown in this timeslot</source>
        <translation>Wekelijkse vertoningen opnemen in dit tijdsblok</translation>
    </message>
</context>
<context>
    <name>ProgLister</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="obsolete">Neem enkel deze vertoning op</translation>
    </message>
    <message>
        <source>Recording every day when shown in this timeslot</source>
        <translation type="obsolete">Dagelijkse vertoningen opnemen in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording every week when shown in this timeslot</source>
        <translation type="obsolete">Wekelijkse vertoningen opnemen in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="obsolete">Neem enkel vertoningen op dit kanaal op</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="obsolete">Neem alle vertoningen op</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="obsolete">Neem deze vertoning niet op</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Fout!</translation>
    </message>
</context>
<context>
    <name>ProgramRecPriority</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="unfinished">Neem enkel deze vertoning op</translation>
    </message>
    <message>
        <source>Recording every week</source>
        <translation type="unfinished">Neem wekelijks op</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="unfinished">Neem enkel vertoningen op in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="unfinished">Neem enkel vertoningen op dit kanaal op</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="unfinished">Neem alle vertoningen op</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="unfinished">Neem deze vertoning niet op</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="unfinished">Fout!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you really want to exit MythTV?</source>
        <translation>Bent U zeker dat U MythTV wil afsluiten?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <source>Yes, Exit now</source>
        <translation>Ja, sluit nu af</translation>
    </message>
    <message>
        <source>Yes, Exit and shutdown the computer</source>
        <translation type="obsolete">Ja, sluit nu af en zet de computer uit</translation>
    </message>
    <message>
        <source>cut point</source>
        <translation>knippunt</translation>
    </message>
    <message>
        <source>keyframe</source>
        <translation>sleutelframe</translation>
    </message>
    <message>
        <source>1 frame</source>
        <translation>1 frame</translation>
    </message>
    <message>
        <source>0.5 seconds</source>
        <translation>0,5 seconden</translation>
    </message>
    <message>
        <source>1 second</source>
        <translation>1 seconde</translation>
    </message>
    <message>
        <source>5 seconds</source>
        <translation>5 seconden</translation>
    </message>
    <message>
        <source>20 seconds</source>
        <translation>20 seconden</translation>
    </message>
    <message>
        <source>1 minute</source>
        <translation>1 minuut</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 minuten</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 minuten</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>You are close to an existing cut point.  Would you like to:</source>
        <translation>Een bestaande knippunt is dichtbij. Wenst U:</translation>
    </message>
    <message>
        <source>Delete this cut point</source>
        <translation>Dit knippunt te verwijderen</translation>
    </message>
    <message>
        <source>Move this cut point to the current position</source>
        <translation>Dit knippunt naar hier te verplaatsen</translation>
    </message>
    <message>
        <source>Flip directions - delete to the </source>
        <translation>De richting om te draaien - verwijder naar </translation>
    </message>
    <message>
        <source>right</source>
        <translation>rechts</translation>
    </message>
    <message>
        <source>left</source>
        <translation>links</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Insert a new cut point?</source>
        <translation>Een nieuw knippunt toevoegen?</translation>
    </message>
    <message>
        <source>Delete before this frame</source>
        <translation>Verwijder voor dit frame</translation>
    </message>
    <message>
        <source>Delete after this frame</source>
        <translation>Verwijder na dit frame</translation>
    </message>
    <message>
        <source>Auto-Skip %1 seconds</source>
        <translation type="obsolete">Automatisch %1 seconden overslaan</translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">Overslaan</translation>
    </message>
    <message>
        <source>Found %1 sec. commercial</source>
        <translation>%1 seconden reclame gevonden</translation>
    </message>
    <message>
        <source>At Start of program.</source>
        <translation type="obsolete">In het begin.</translation>
    </message>
    <message>
        <source>At End, can not Skip.</source>
        <translation>Op het einde, kan niet Overslaan.</translation>
    </message>
    <message>
        <source>Start of program.</source>
        <translation>Begin van programma.</translation>
    </message>
    <message>
        <source>cut</source>
        <translation>knip</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Plannen</translation>
    </message>
    <message>
        <source>Do not record this proram</source>
        <translation type="obsolete">Dit programma niet opnemen</translation>
    </message>
    <message>
        <source>Record only this showing</source>
        <translation>Enkel deze vertoning van het programma opnemen</translation>
    </message>
    <message>
        <source>Record in this timeslot every day</source>
        <translation>Dit programma dagelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Record at any time on this channel</source>
        <translation>Dit programma altijd op dit kanaal opnemen</translation>
    </message>
    <message>
        <source>Record at any time on any channel</source>
        <translation>Dit programma altijd en op alle kanalen opnemen</translation>
    </message>
    <message>
        <source>Record in this timeslot every week</source>
        <translation>Dit programma wekelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Do not record this program</source>
        <translation>Dit programma niet opnemen</translation>
    </message>
    <message>
        <source>Record only this showing of the program</source>
        <translation type="obsolete">Enkel deze vertoning van het programma opnemen</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every day</source>
        <translation type="obsolete">Dit programma dagelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown on this channel</source>
        <translation type="obsolete">Dit programma altijd op dit kanaal opnemen</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown anywhere</source>
        <translation type="obsolete">Dit programma altijd en op alle kanalen opnemen</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every week</source>
        <translation type="obsolete">Dit programma wekelijks in dit tijdsblok opnemen</translation>
    </message>
    <message>
        <source>Profile</source>
        <translation>Profiel</translation>
    </message>
    <message>
        <source>(unspecified)</source>
        <translation>Automatisch %1 seconden overslaan</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="obsolete">Rang</translation>
    </message>
    <message>
        <source>Record duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum number of episodes to keep (set to 0 for ALL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record new episodes and delete oldest once maximum count is reached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind  --  %.2f%% full</source>
        <translation type="unfinished">%02d:%02d:%02d achter  --  %.2f%% vol</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind</source>
        <translation type="unfinished">%02d:%02d:%02d achter</translation>
    </message>
    <message>
        <source>%02d:%02d behind  --  %.2f%% full</source>
        <translation type="unfinished">%02d:%02d achter  --  %.2f%% vol</translation>
    </message>
    <message>
        <source>%02d:%02d behind</source>
        <translation type="unfinished">%02d:%02d achter</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d of %02d:%02d:%02d</source>
        <translation type="unfinished">%02d:%02d:%02d van %02d:%02d:%02d</translation>
    </message>
    <message>
        <source>%02d:%02d of %02d:%02d</source>
        <translation type="unfinished">%02d:%02d van %02d:%02d</translation>
    </message>
    <message>
        <source>Skip %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Recording</source>
        <translation type="unfinished">Niet Opnemen</translation>
    </message>
    <message>
        <source>Recording Once</source>
        <translation type="obsolete">Eenmalig Opnemen</translation>
    </message>
    <message>
        <source>Timeslot Recording</source>
        <translation type="obsolete">Opnemen per Tijdsblok</translation>
    </message>
    <message>
        <source>Channel Recording</source>
        <translation type="unfinished">Opnemen per Kanaal</translation>
    </message>
    <message>
        <source>All Recording</source>
        <translation type="unfinished">Alles Opnemen</translation>
    </message>
    <message>
        <source>Air Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Schedule:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pre-scaling theme images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio output device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use internal volume controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV can control the PCM and master mixer volume.  If you prefer to use an external mixer program, uncheck this box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mixer Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changing the volume adjusts the selected mixer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Master Mixer Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial volume for the Master Mixer.  This affects all sound created by the soundcard.  Note: Do not set this too low.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM Mixer Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial volume for PCM output.  Use of the volume keys in MythTV will adjust this parameter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deinterlace playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make the video look normal on a progressive display (i.e. monitor).  Deinterlace requires that your CPU supports SSE instructions.  Enabling this without proper CPU support will cause the program to segfault. See the HOWTO document for more information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extra audio buffering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This attempts to keep extra audio data in the internal buffers.  Try setting this if you&apos;re getting crackly audio. (Not used for software encoded video.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jump amount (in minutes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many minutes to jump forward or backward when the jump keys are pressed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast forward amount (in seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many seconds to skip forward on a fast forward.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rewind amount (in seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many seconds to skip backward on a rewind.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek to exact frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If enabled, seeking is frame exact, but slower.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial Skip Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blank Frame Detection (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blank Frame + Scene Change Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene Change Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This determines the method used by MythTV to detect when commercials start and end.  You must have automatic commercial turned on to use anything other than &apos;Blank Frame&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Skip Commercials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Flag Commercials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically flag commercials after a recording completes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strict Commercial Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on stricter Commercial Detection code.  If some commercials are not being detected, try turning this setting OFF.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire Free Disk Space Threshold (in Gigabytes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trigger AutoExpire when free space in Gigabytes goes below this value.  Turn OFF AutoExpire by setting to 0.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire Frequency (in minutes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of minutes the AutoExpire process will wait between each time that it checks for free disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oldest Show First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method used to determine which recorded shows to AutoExpire first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Expire Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn Auto-Expire ON by default when creating new scheduled recordings.  Existing scheduled recordings will keep their current value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Recording Free Disk Space Threshold (in Megabytes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV will stop scheduling new recordings on a backend when its free disk space falls below this value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time to record before start of show (in seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time to record past end of show (in seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Newest Recording First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked (default) the most recent recording will be listed first in the &apos;Watch Recordings&apos; screen. If unchecked the oldest recording will be listed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticky keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, fast forward and rewind continue after the key is released.  Pressing the key again increases the fast forward or rewind speed.  The alternate fast forward and rewind keys always behave in this way.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setup Pin Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This PIN is used to control access to the setup menues. If you want to use this feature, then setting the value to all numbers will make your life much easier.  Set it to blank to disable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Require Setup PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Setup PIN without first entering the current PIN.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reposition after fast forward/rewind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When exiting sticky keys fast forward/rewind mode, reposition before resuming normal playback.  This is to compensate for the reaction time between seeing where to resume playback and actually exiting fast forward/rewind mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of seconds for OSD information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How long the program information remains on the On Screen Display after a channel change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OSD theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OSD font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closed Caption font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel ordering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel number (numeric)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel number (alpha)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>database order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical over/underscan percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this if the image does not fill your screen vertically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal over/underscan percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this if the image does not fill your screen horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan displacement (X)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this to move the image horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan displacement (Y)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this to move the image vertically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jitter reduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, frame timing will be adjusted for smoother motion.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Experimental A/V Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, more experimental code will be in charge of video output. Use at your own risk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default setting for Closed Captioning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, captions will be on by default when playing back recordings or watching live TV.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use Browse mode when changing channels in LiveTV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, Browse mode will automatically be activated whenever you use Channel UP/DOWN when watching Live TV.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aggressive Soundcard Buffering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, MythTV will pretend to have a smaller soundcard buffer than is really present.  This may speed up seeking, but can also cause playback problems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Saved Position on playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically clear saved position on a recording when the recording is played back.  If UNset, you can mark the beginning with rewind then save position.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Clear Saved Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, during playback the select key (Enter or Space) will alternate between &quot;Position Saved&quot; and &quot;Position Cleared&quot;. If UNset, select will save the current position for each keypress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action on playback exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Just exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save position and exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to prompt, a menu will be displayed when you exit playback mode.  The options available will allow you to save your position, delete the recording, or continue watching.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt at end of recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a menu will be displayed allowing you to delete the recording when it has finished playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate thumbnail preview images for recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a static image of the recording will be displayed on the &quot;Watch a Recording&quot; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display live preview of recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a preview of the recording will play in a small window on the &quot;Watch a Recording&quot; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Transparent Boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the Watch Recording and Delete Recording screens will use transparency. Unset this option if selecting the recordings is slow.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popup Background Shading Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill is the quickest method, but it doesn&apos;t look good up close. Image looks good from up close, but is somewhat slow. And of course no shading will be the fastest.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use Advanced Recording Options screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use the Advanced Recording Options screen when editing a scheduled recording.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No exit key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Control-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV is designed to run continuously. If you wish, you may use the ESC key or the ESC key + a modifier to exit MythTV. Do not choose a key combination that will be intercepted by your window manager.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Halt command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have configured an exit key on the System Shutdown menu, you will be given the opportunity to exit MythTV or halt the system completely. Another possibility for this field is poweroff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xinerama screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If using Xinerama, run only on the specified screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The width of the GUI.  Do not make the GUI wider than your actual screen resolution.  Set to 0 to automatically scale to fullscreen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The height of the GUI.  Do not make the GUI taller than your actual screen resolution.  Set to 0 to automatically scale to fullscreen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI X offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The horizontal offset the GUI will be displayed at.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI Y offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The vertical offset the GUI will be displayed at.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run the frontend in a window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggles between borderless operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a random theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a random theme each time MythTV is started.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd MMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd MMMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MM/dd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MM.dd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd d MMM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd.MM.yyyy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred date format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short Date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>M/d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d/M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd/MM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d.M.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd.MM.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred short date format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm AP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm ap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm AP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm ap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred time format.  Choose a format with &quot;AP&quot; in it for an AM/PM display, otherwise your time display will be 24-hour or &quot;military&quot; time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Problem reading theme preview image </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display channel names instead of numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Big&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Medium&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Small&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Guide Selection Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If unchecked, the program guide&apos;s selector will stay in the middle of the guide at all times.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guide Shading Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorized (alpha)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorized (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embossed (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embossed (solid)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rounded (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rounded (solid)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display the channel icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels to Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Blocks (30 mins) to Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guide starts at channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The program guide starts on this channel if it is run from outside of LiveTV mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What to call &apos;unknown&apos; programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What category to give &apos;unknown&apos; programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Xbox Hardware</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This enables support for Xbox Specific hardware. Requires a frontend restart for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xbox Linux Distribution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is used to determine the name of the blink binary led will be used on GentooX, blink otherwise.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default LED mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This sets the LED mode when there is nothing else to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording LED mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This sets the LED mode when a backend is recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording Check Frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This specifies how often in seconds to check if a recording is in progress and update the Xbox LED.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seeking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overscan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On-screen display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global Auto Expire Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Guide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screen settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Localization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Create new profile group)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MP3 Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The higher the slider number, the lower the quality of the audio.  Better quality audio (lower numbers) requires more CPU.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio sampling rate for your DSP. Ensure that you choose a sampling rate appropriate for your device.  btaudio may only allow 32000.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume of the recording </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RTjpeg Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Higher is better quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luma filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower is better.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chroma filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate in kilobits/second.  2200Kbps is approximately 1 Gigabyte per hour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale bitrate for frame size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 bitrate will be used for 640x480.  If other resolutions are used, the bitrate will be scaled appropriately.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modifying the default may have severe consequences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max quality difference between frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable high-quality encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 encoder will use &apos;high-quality&apos; encoding options.  This requires much more processing, but can result in better video.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable 4MV encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 encoder will use &apos;4MV&apos; motion-vector encoding.  This requires much more processing, but can result in better video. It is highly recommended that the HQ option is enabled if 4MV is enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Bitrate in kilobits/second.  2200Kbps is approximately 1 Gigabyte per hour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the type of stream generated by your PVR.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Square</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the aspect ratio of stream generated by your PVR.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal Decimation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Decimation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RTjpeg Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG-4 Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware MJPEG Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG-2 Hardware Encoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically transcode after recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mixer Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Fast Forwarding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If enabled, then immediately after rewinding, only skip forward the same amount as skipping backwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Xv picture controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, Xv picture controls (brightness, contrast, etc.) are used during playback. These are independent of the v4l controls used for recording. The Xv controls may not work properly on some systems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the PVR-350&apos;s TV out / MPEG decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV can use the PVR-350&apos;s TV out and MPEG decoder for high quality playback.  This requires that the ivtv-fb kernel module is also loaded and set up properly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video device for the PVR-350 MPEG decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PVR-350 Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Filter configuration, format:
[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>big</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default: TV, small: monitor, big:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change channels immediately without select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General playback (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial: %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pre-Roll Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post-Roll Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify, but do not skip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Skip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP Notify Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip blank frames after commercials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Recording on cardid: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Recording: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual Override</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previously Recorded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Currently Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Showing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too Many Recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Record List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower Rec Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reason Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daily Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly Recording</source>
        <translation type="unfinished">Wekelijks Opnemen</translation>
    </message>
    <message>
        <source>Conflicting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Will Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Won&apos;t Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t record it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never record this episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record it anyway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember this choice and use it automatically in the future</source>
        <translation type="unfinished">Onthou deze keuze en gebruik ze later automatisch</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AC3 to SPDIF passthrough</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PIP Video Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of PIP Video window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reverse direction in fast forward/rewind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Recording Priorities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use program recording priorities to resolve conflicts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording Priorities First.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekslot Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekslot Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeslot Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeslot Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Recording types will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Recording Priorities Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, Exit and Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RankPrograms</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="obsolete">Neem enkel deze vertoning op</translation>
    </message>
    <message>
        <source>Recording every week</source>
        <translation type="obsolete">Neem wekelijks op</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="obsolete">Neem enkel vertoningen op in dit tijdsblok</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="obsolete">Neem enkel vertoningen op dit kanaal op</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="obsolete">Neem alle vertoningen op</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="obsolete">Neem deze vertoning niet op</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Fout!</translation>
    </message>
</context>
<context>
    <name>ScheduledRecording</name>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Aflevering:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Beschrijving:</translation>
    </message>
    <message>
        <source>Advanced Recording Options</source>
        <translation type="obsolete">Geavanceerde Opname Opties</translation>
    </message>
    <message>
        <source>See a list of all up-coming episodes/playtimes.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SetRecTimeDialog</name>
    <message>
        <source>Change recording time:</source>
        <translation type="obsolete">Wijzig opname-tijd:</translation>
    </message>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Aflevering:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Beschrijving:</translation>
    </message>
    <message>
        <source>Start Time: </source>
        <translation type="obsolete">Begintijd:</translation>
    </message>
    <message>
        <source>End Time: </source>
        <translation type="obsolete">Eindtijd:</translation>
    </message>
</context>
<context>
    <name>TV</name>
    <message>
        <source>MythTV is already using all available inputs for recording.  If you want to watch an in-progress recording, select one from the playback menu.  If you want to watch live TV, cancel one of the in-progress recordings from the delete menu.</source>
        <translation>MythTV gebruikt reeds alle opname-ingangen. Als U een opname wilt bekijken die nu wordt opgenomen, selecteer ze dan in het menu Opnames Bekijken. Als U live TV wilt bekijken, annuleer dan de huidige opname in het menu Opnames Verwijderen.</translation>
    </message>
    <message>
        <source>Cancel and go back to the TV menu</source>
        <translation>Annuleer en keer terug naar het TV-menu</translation>
    </message>
    <message>
        <source>Record and watch while it records</source>
        <translation>Neem op en bekijk tijdens het opnemen.</translation>
    </message>
    <message>
        <source>Let it record and go back to the Main Menu</source>
        <translation>Neem op en keer terug naar menu.</translation>
    </message>
    <message>
        <source>Don&apos;t let it record, I want to watch TV</source>
        <translation>Neem niet op, ik wil live TV bekijken</translation>
    </message>
    <message>
        <source>You are exiting this recording</source>
        <translation>U sluit deze opname af</translation>
    </message>
    <message>
        <source>Save this position and go to the menu</source>
        <translation>Bewaar deze positie en keer terug naar het menu</translation>
    </message>
    <message>
        <source>Do not save, just exit to the menu</source>
        <translation>Bewaar deze positie niet en keer terug naar het menu</translation>
    </message>
    <message>
        <source>Keep watching</source>
        <translation>Blijf kijken</translation>
    </message>
    <message>
        <source>Delete this recording</source>
        <translation>Verwijder deze opname</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind  --  %.2f%% full</source>
        <translation type="obsolete">%02d:%02d:%02d achter  --  %.2f%% vol</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind</source>
        <translation type="obsolete">%02d:%02d:%02d achter</translation>
    </message>
    <message>
        <source>%02d:%02d behind  --  %.2f%% full</source>
        <translation type="obsolete">%02d:%02d achter  --  %.2f%% vol</translation>
    </message>
    <message>
        <source>%02d:%02d behind</source>
        <translation type="obsolete">%02d:%02d achter</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d of %02d:%02d:%02d</source>
        <translation type="obsolete">%02d:%02d:%02d van %02d:%02d:%02d</translation>
    </message>
    <message>
        <source>%02d:%02d of %02d:%02d</source>
        <translation type="obsolete">%02d:%02d van %02d:%02d</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <source>Forward </source>
        <translation>Voorwaarts </translation>
    </message>
    <message>
        <source>Rewind </source>
        <translation>Achterwaarts </translation>
    </message>
    <message>
        <source>Jump Ahead</source>
        <translation>Spring vooruit</translation>
    </message>
    <message>
        <source>Jump Back</source>
        <translation>Spring achteruit</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Bezig met zoeken...</translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">Overslaan</translation>
    </message>
    <message>
        <source>Brightness %1 %</source>
        <translation>Helderheid %1 %</translation>
    </message>
    <message>
        <source>Adjust Picture</source>
        <translation>Beeld aanpassen</translation>
    </message>
    <message>
        <source>Contrast %1 %</source>
        <translation>Contrast %1 %</translation>
    </message>
    <message>
        <source>Colour %1 %</source>
        <translation>Kleur %1 %</translation>
    </message>
    <message>
        <source>Volume %1 %</source>
        <translation>Volume %1 %</translation>
    </message>
    <message>
        <source>Adjust Volume</source>
        <translation>Volume wijzigen</translation>
    </message>
    <message>
        <source>Mute On</source>
        <translation>Geluid uit</translation>
    </message>
    <message>
        <source>Mute Off</source>
        <translation>Geluid aan</translation>
    </message>
    <message>
        <source>Transcode</source>
        <translation type="obsolete">Omzetten</translation>
    </message>
    <message>
        <source>Hue %1 %</source>
        <translation>Hue %1 %</translation>
    </message>
    <message>
        <source>Stopping Transcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip Ahead</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 5X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 3X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 2X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 1/3X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 1/8X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed 1/16X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16:9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4:3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is currently being edited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue Editing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brightness (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contrast (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colour (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hue (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip to Notify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Auto Expire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleer</translation>
    </message>
    <message>
        <source>Auto-Skip OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Skip ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Skip Notify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16:9 Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4:3 Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewScheduled</name>
    <message>
        <source>Time Conflict</source>
        <translation>Tijdsconflict</translation>
    </message>
    <message>
        <source>No Conflicts</source>
        <translation>Geen conflicten</translation>
    </message>
    <message>
        <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
        <translation type="obsolete">Opname van dit programma is gedesactiveerd omdat het in conflict is met een andere opname. Wilt U deze opname heractiveren?</translation>
    </message>
    <message>
        <source>Yes, I want to record it.</source>
        <translation type="obsolete">Ja, ik wil het opnemen.</translation>
    </message>
    <message>
        <source>No, leave it disabled.</source>
        <translation type="obsolete">Nee, laat het gedesactiveerd.</translation>
    </message>
    <message>
        <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
        <translation type="obsolete">Opname van dit programma is uitgeschakeld, omdat het vroeger al is opgenomen.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
        <translation type="obsolete">De volgende opnames zijn in conflict. Welk programma wenst U op te nemen?</translation>
    </message>
    <message>
        <source>Remember this choice and use it automatically in the future</source>
        <translation type="obsolete">Onthou deze keuze en gebruik ze later automatisch</translation>
    </message>
    <message>
        <source>Unsuppress recording</source>
        <translation type="obsolete">Heractiveer opname</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Important</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
